@@ -4,12 +4,12 @@ from typing import Dict, List, Optional
 
 import uvicorn
 from fastapi import FastAPI
-
 from lof.code_gen import create_temp_app_folder, generate_app
 from lof.env_vars import path_for_env_file, set_env_variables
 from lof.errors import NoTemplate, NoVariablesFile
-from lof.generator import create_route, create_middleware
+from lof.generator import create_middleware, create_route
 from lof.parser import get_endpoints
+from lof.aws_context import Context
 
 
 def validate_paths(template_file: str, variables_file: str) -> None:
@@ -29,13 +29,11 @@ def add_template_path_to_python_paths(template_file: str, layers: List[str]) ->
         sys.path.insert(0, layer)
 
 
-def run_fast_api_server(
-    lambdas: List[Dict], 
-    proxy_lambdas: List[Dict]
-) -> FastAPI:
+def run_fast_api_server(lambdas: List[Dict], proxy_lambdas: List[Dict]) -> FastAPI:
 
     app = FastAPI()
-    
+    app.context = Context
+
     create_middleware(proxy_lambdas=proxy_lambdas, app=app)
 
     for _lambda in lambdas:
@@ -44,6 +42,7 @@ def run_fast_api_server(
             method=_lambda["method"],
             handler=_lambda["handler"],
             app=app,
+            lambda_name=_lambda["name"]
         )
     return app
 
@@ -56,7 +55,7 @@ def run_multiple_workers_app(
     debug: bool,
     reload: bool,
     variables_file: str,
-    proxy_lambdas: List[Dict]
+    proxy_lambdas: List[Dict],
 ) -> None:
     lof_dir = create_temp_app_folder()
     env_file = None
@@ -89,7 +88,9 @@ def runner(
         raise ValueError("Count of workers cannot be less when 1")
 
     validate_paths(template_file, variables_file)
-    lambdas, layers, proxy_lambdas = get_endpoints(template_file, exclude, proxy_lambdas)
+    lambdas, layers, proxy_lambdas = get_endpoints(
+        template_file, exclude, proxy_lambdas
+    )
 
     add_template_path_to_python_paths(template_file, layers)
 
@@ -98,17 +99,16 @@ def runner(
 
     if workers == 1 and not reload:
 
-        app = run_fast_api_server(
-            lambdas=lambdas,
-            proxy_lambdas=proxy_lambdas
-        )
+        app = run_fast_api_server(lambdas=lambdas, proxy_lambdas=proxy_lambdas)
         uvicorn.run(app, host=host, port=port, debug=debug)
     else:
         run_multiple_workers_app(
             lambdas=lambdas,
-            port=port, 
-            host=host, 
-            workers=workers, 
-            debug=debug, 
-            reload=reload, variables_file=variables_file, proxy_lambdas=proxy_lambdas
+            port=port,
+            host=host,
+            workers=workers,
+            debug=debug,
+            reload=reload,
+            variables_file=variables_file,
+            proxy_lambdas=proxy_lambdas,
         )
