@@ -43,12 +43,16 @@ def get_endpoints(
             elif "AWS::Serverless::LayerVersion" in resource_data["Type"]:
                 layers.append(resource_data["Properties"]["ContentUri"])
 
-    lambdas, proxy_lambdas = process_lambdas_resources(_resources, exclude, proxy_lambdas)
+    lambdas, proxy_lambdas = process_lambdas_resources(
+        _resources, exclude, proxy_lambdas
+    )
 
     return lambdas, layers, proxy_lambdas
 
 
-def process_lambdas_resources(resources: Dict, exclude: List[str], proxy_lambdas: List[str]) -> List[Dict]:
+def process_lambdas_resources(
+    resources: Dict, exclude: List[str], proxy_lambdas: List[str]
+) -> List[Dict]:
     lambdas = []
     p_lambdas = []
     for lambda_name, data in resources.items():
@@ -59,8 +63,7 @@ def process_lambdas_resources(resources: Dict, exclude: List[str], proxy_lambdas
             handler = f"{code_uri}{data['Properties']['Handler']}"
             events = data["Properties"].get("Events")
             if lambda_name in proxy_lambdas:
-                p_lambdas.append({"name": lambda_name, 
-                                         "handler": handler})
+                p_lambdas.append({"name": lambda_name, "handler": handler})
                 continue
             if not events:
                 # mean it is authorizer or smth relative
